冰川时代 (豆瓣)
Description: 冰川时代电影简介和剧情介绍,冰川时代影评、图片、预告片、影讯、论坛、在线购票
Keywords: 冰川时代,Ice Age,冰川时代影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.189豆瓣电影Top250

# 冰川时代 Ice Age (2002)

导演: 卡洛斯·沙尔丹哈 / 克里斯·韦奇
编剧: 迈克尔·伯格 / 迈克尔·J·威尔森 / 彼得·阿克曼
主演: 雷·罗马诺 / 约翰·雷吉扎莫 / 丹尼斯·利瑞 / 杰克·布莱克
类型: 喜剧 / 动画 / 冒险
制片国家/地区: 美国
语言: 英语 / 克罗地亚语
上映日期: 2002-03-15(美国)
片长: 81分钟
又名: 冰河世纪 / 冰原历险记
IMDb: tt0268380
豆瓣评分
引用
8.6
584010人评价
5星
43.3%
4星
45.3%
3星
10.8%
2星
0.5%
1星
0.1%
好于 96% 动画片
好于 98% 喜剧片
想看 看过
评价:
推荐

## 冰川时代的剧情简介 · · · · · ·

冰河时期降至，动物们都急着迁徙到温暖的地方及储存食物。长毛象曼弗瑞德、树獭希德、剑齿虎迪亚戈为了帮助一个人类的婴儿回到父母身边，因而也掉了动物们迁徙的队伍。三只性格各异的动物，觉得集合力量帮助婴儿。一路上，善良的曼弗瑞德总觉得迪亚戈心怀鬼胎，想吃掉婴儿，互相猜疑。他们一起经历了无数艰难险阻，终于能够真诚相对。
当剑齿虎迪亚戈的同伴知道它身边正有一个婴儿，饥寒交迫的它们就想迪亚戈把婴儿交给它们当食物，迪亚戈已对可爱的小婴儿产生了感情，无法下手，而迪亚戈该如何选择呢？小婴儿又能否安全回到家中？ ©豆瓣

## 冰川时代的演职员 · · · · · · ( 全部 22 )

- 卡洛斯·沙尔丹哈 导演
- 克里斯·韦奇 导演
- 雷·罗马诺 配音
- 约翰·雷吉扎莫 配音
- 丹尼斯·利瑞 配音
- 杰克·布莱克 配音

## 冰川时代的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片360 · 添加 )

## 冰川时代的获奖情况 · · · · · · ( 全部 )

- 第75届奥斯卡金像奖
- 最佳动画长片(提名)
- 克里斯·韦奇

- 第30届动画安妮奖
- 最佳动画长片(提名)

- 第30届动画安妮奖
- 最佳导演(提名)
- 卡洛斯·沙尔丹哈 / 克里斯·韦奇

## 喜欢这部电影的人也喜欢 · · · · · ·

  冰川时代2：融冰之灾

  大闹天宫

  天空之城

  哪吒闹海

  玩具总动员

  怪兽电力公司

  幽灵公主

  风之谷

  哈尔的移动城堡

  神偷奶爸

我要写短评

## 冰川时代的短评 · · · · · · ( 全部 56907 条 )

热门 / 最新 / 好友

### 367 有用 肖浑 看过 2009-07-17 00:19:58

不同类，要成为集体，是多么艰难，又是多么简单 类与类融合很难，个体与个体相爱很简单 爱都是个人的事，与种族无关

### 494 有用 沉歌 看过 2008-05-03 18:37:02

很久很久以前的冰河世纪，一只剑齿虎攻和一只树赖受相遇了……最后他们和宠物长毛象幸福的生活在了一起。THE END~

### 252 有用 影志 看过 2006-02-04 06:23:22

成年后再次接触动画片的最初几部，当年刚上大一，跟《怪物史瑞克》一样刷新了我们整个宿舍的眼界，动画片可以这样精彩和不分年龄。

### 741 有用 王老虎 看过 2008-06-27 20:13:37

这只松鼠才是角儿！

### 157 有用 巴喆 看过 2012-02-18 22:47:36

说明了人类的孤芳自赏与自大无知，在史前一万年前动物们就已经知道如此了。老虎都这么有情，叫那小孩情何以堪。原来唯一不会使用英语的竟是人类，更讶异的是，那小松鼠直接改变地球生物史。8

> 更多短评 56907条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 冰川时代的影评 · · · · · · ( 全部 277 条 )

热门 / 最新 / 好友
幽犽 2009-07-19 11:31:00

## 冰河世纪

很少这么认真的看一部动画电影，但冰河世纪给了我太多感动。 人类在这部电影里多少扮演着一个残酷的角色，给所有的动物们都带来了痛苦，无论是善良的长毛象曼弗瑞德，还是扮演了大反派的剑齿虎，他们都因人类失去了同伴。 在这短短的旅程里，这些动物给了我太多感动。 因为人类... (展开)
105 2 15回应 收起
lullaby 2006-02-19 14:43:57

## 好莱坞的必备良药

近年来每每看好莱坞的动画作品，总能得到美美的享受。 最令人难忘的不是她一贯的主题，比如爱，比如勇敢，比如宽恕等等，虽然这些主题讲的那么自然不做作不说教。 最有意思的就是电影总能让人那么开心，尤其是主角的个性，多半是个小个子的家伙罗里罗嗦却是插科打诨妙趣因之生... (展开)
81 3 17回应 收起
大医精诚 2018-05-31 15:57:34

## 特别可爱的动物们，松鼠实力抢镜

冰河世纪里的一个温馨故事：尖酸刻薄的毛象， 粗野狡黠的树獭以及诡计多端的剑虎。 怀着不同的目的凑在一起，走上送宝宝回家的旅途。 在这一路上，他们互相了解，他们互相帮助，最终把宝宝送回家。 它用很浅显的故事告诉我们：爱心、责任、友爱、团队精神。 第一集《冰河世纪》... (展开)
59 2回应 收起
北极苹果 2009-07-12 22:24:17

## 好想做只小松鼠

死死的抱著自己的松果不放，是不是很傻很可爱？哪怕过了两万年，也会因为松果被海浪吹跑恨恨不已。 (展开)
36 2 12回应 收起
小人鱼 2017-05-15 08:56:40

## 远古时代的温情

这篇影评可能有剧透

这部电影第一次是在初中时候看的，当时特别喜欢，直到现在上了大学，冰河世纪依旧是最喜欢的系列影片，里面的猛犸象，剑齿虎和树懒也是最喜欢的角色，当然，还有那只松鼠…… 在这部电影里，最大的看点是三只动物对于婴儿的感情以及人类的残酷。曼尼，迪亚哥和希德都是因为人类... (展开)
23 1回应 收起
红装素裹 2018-03-05 08:24:17

## 那个时代的动物们

非常喜欢这部动画片，第一次看到《冰川时代》是小学的时候，站在商场里的彩电展示柜前，里面有个傻傻的松鼠拼了命去追逐一个总是吃不到嘴的松子。我在这部电影里看到了温暖，因为人类的行为而给多少生灵带来痛苦。曼弗瑞德的包容和友爱，来搞笑的希德，和我始终当反派来看待的... (展开)
37 0回应 收起
jfflnzw 2017-08-20 21:38:53

## 可爱的故事

故事围绕着三只冰河时期的史前动物和一个人类弃婴展开。冰河期使得动物们纷纷迁移寻找食物。心地善良的长毛象——曼弗瑞德、嗜食的树獭——希德、狡猾的剑齿虎——迪亚戈，这三只性格迥异的动物为了使一个人类的小孩重返家园，竟然聚在了一起，组成了一只临时护送队，踏上了漫... (展开)
24 0回应 收起
莫里幽白 2018-06-20 20:47:36

## 都有温柔的一面

到目前为止，我们都没有在银河系的其他星球发现生命的迹象，很荒凉~所以，我们能够生活在地球这颗璀璨的星球上，真的狠幸运！ 原谅我一直不讲述正题，因为这部电影真的是讲叙了人与动物的各种关系，作为生物链上面的最高层，我们真的很少考虑到下层生物的感觉。 看到大象回忆起... (展开)
23 0回应 收起
立夏Alex 2017-05-16 15:45:53

## 冰川时代

我正忙着做梦 一瞬间冲动 为什么某个大楼毁灭整个星球 沉睡中那苍白的脸看世界在变 这就是静着后完整的脸 将毁灭这一切 等到我到达世界尽头 以后会不会有人在很远的地方守候 那是什么样的自由 在领易世界的尽头 WO WO WO 午夜世界的尽头 WO WO WO 午夜世界的尽头 但是你已不在 ... (展开)
12 0回应 收起
奇小一 2017-06-15 21:26:18

## 冰川时代

它讲了在二万年前，地球正面临残酷的冰川时期，在无情的冰天雪地下，树lǎn懒、毛象、电chí虎产生了友爱情谊，互相帮助，战胜困难，历尽千辛万苦把一个人类的孩子送到了亲人的怀抱。 当毛象把孩子送到她亲人怀抱的时候，我禁不住流下了眼泪。原来动物也是有感情的，只要我们不... (展开)
8 0回应 收起

> 更多影评 277篇

添加新讨论

## 讨论区 · · · · · ·

经典的一部动画片 | 来自豆友KoqE-VaKt8 |  | 2022-09-25 21:58:06
最爱松鼠 | 来自..愫 |  | 2022-09-23 06:55:39
一定要看台湾配音版 | 来自suda | 11 回应 | 2022-09-10 22:41:10
最近特想重温，但全网都找不到啊，买光盘都没地去... | 来自Sucre | 12 回应 | 2022-09-09 18:15:09
几个不懂的地方 | 来自GAL |  | 2022-08-31 02:37:53

> 去这部影片的讨论区（全部94条）

## 关于《冰川时代》的问题 · · · · · · ( 全部3个 )

- 求助！有了解百老汇的冰川时代冰上秀来到国内这件事的人吗？ 2人回答
- 只有我死都看不慣美國電影裏邊這類長相的死小孩麼？ 7人回答

> 全部3个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 芒果TV VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- 【励志电影】 (影志)
- 【豆瓣高分动画长片】 (影志)
- 那些和谐的腐剧，腐动画，腐电影们。 (墨 尘)
- {北美电影票房总排行} (荔枝超人)
- 【爱看动画】 (影志)

## 谁在看这部电影 · · · · · ·

- 墨央子
  3分钟前 看过
- 落落的暮暮
  7分钟前 看过
- 杨坚强
  10分钟前 看过

1143563人看过 / 75198人想看

订阅冰川时代的评论:
feed: rss 2.0